// src/components/TableComponent.tsx
import { useEffect as useEffect4, useState as useState4, useRef as useRef2 } from "react";

// src/components/NoContentComponent.tsx
import { jsx, jsxs } from "react/jsx-runtime";
var NoContentComponent = ({
  name = "items",
  text,
  icon
}) => /* @__PURE__ */ jsxs("div", { className: "text-center py-10", children: [
  icon ? icon : /* @__PURE__ */ jsx(
    "svg",
    {
      className: "mx-auto h-12 w-12 text-gray-400",
      fill: "none",
      viewBox: "0 0 24 24",
      stroke: "currentColor",
      children: /* @__PURE__ */ jsx(
        "path",
        {
          strokeLinecap: "round",
          strokeLinejoin: "round",
          strokeWidth: 2,
          d: "M13 10V3L4 14h7v7l9-11h-7z"
        }
      )
    }
  ),
  /* @__PURE__ */ jsx("p", { className: "text-gray-500", children: text ? text : `No ${name} found.` })
] });
var NoContentComponent_default = NoContentComponent;

// src/components/TableSkeleton.tsx
import { useEffect, useState } from "react";

// node_modules/react-loading-skeleton/dist/index.js
import React from "react";
var SkeletonThemeContext = React.createContext({});
var defaultEnableAnimation = true;
function styleOptionsToCssProperties({ baseColor, highlightColor, width, height, borderRadius, circle, direction, duration, enableAnimation = defaultEnableAnimation, customHighlightBackground }) {
  const style = {};
  if (direction === "rtl")
    style["--animation-direction"] = "reverse";
  if (typeof duration === "number")
    style["--animation-duration"] = `${duration}s`;
  if (!enableAnimation)
    style["--pseudo-element-display"] = "none";
  if (typeof width === "string" || typeof width === "number")
    style.width = width;
  if (typeof height === "string" || typeof height === "number")
    style.height = height;
  if (typeof borderRadius === "string" || typeof borderRadius === "number")
    style.borderRadius = borderRadius;
  if (circle)
    style.borderRadius = "50%";
  if (typeof baseColor !== "undefined")
    style["--base-color"] = baseColor;
  if (typeof highlightColor !== "undefined")
    style["--highlight-color"] = highlightColor;
  if (typeof customHighlightBackground === "string")
    style["--custom-highlight-background"] = customHighlightBackground;
  return style;
}
function Skeleton({ count = 1, wrapper: Wrapper, className: customClassName, containerClassName, containerTestId, circle = false, style: styleProp, ...originalPropsStyleOptions }) {
  var _a, _b, _c;
  const contextStyleOptions = React.useContext(SkeletonThemeContext);
  const propsStyleOptions = { ...originalPropsStyleOptions };
  for (const [key, value] of Object.entries(originalPropsStyleOptions)) {
    if (typeof value === "undefined") {
      delete propsStyleOptions[key];
    }
  }
  const styleOptions = {
    ...contextStyleOptions,
    ...propsStyleOptions,
    circle
  };
  const style = {
    ...styleProp,
    ...styleOptionsToCssProperties(styleOptions)
  };
  let className = "react-loading-skeleton";
  if (customClassName)
    className += ` ${customClassName}`;
  const inline = (_a = styleOptions.inline) !== null && _a !== void 0 ? _a : false;
  const elements = [];
  const countCeil = Math.ceil(count);
  for (let i = 0; i < countCeil; i++) {
    let thisStyle = style;
    if (countCeil > count && i === countCeil - 1) {
      const width = (_b = thisStyle.width) !== null && _b !== void 0 ? _b : "100%";
      const fractionalPart = count % 1;
      const fractionalWidth = typeof width === "number" ? width * fractionalPart : `calc(${width} * ${fractionalPart})`;
      thisStyle = { ...thisStyle, width: fractionalWidth };
    }
    const skeletonSpan = React.createElement("span", { className, style: thisStyle, key: i }, "\u200C");
    if (inline) {
      elements.push(skeletonSpan);
    } else {
      elements.push(React.createElement(
        React.Fragment,
        { key: i },
        skeletonSpan,
        React.createElement("br", null)
      ));
    }
  }
  return React.createElement("span", { className: containerClassName, "data-testid": containerTestId, "aria-live": "polite", "aria-busy": (_c = styleOptions.enableAnimation) !== null && _c !== void 0 ? _c : defaultEnableAnimation }, Wrapper ? elements.map((el, i) => React.createElement(Wrapper, { key: i }, el)) : elements);
}

// src/components/TableSkeleton.tsx
import { jsx as jsx2, jsxs as jsxs2 } from "react/jsx-runtime";
var TableSkeleton = ({
  disableDefaultStyles = false,
  customClassNames = {},
  enableDarkMode = true
}) => {
  const [isDarkMode, setIsDarkMode] = useState(false);
  useEffect(() => {
    if (enableDarkMode) {
      const matchMedia = window.matchMedia("(prefers-color-scheme: dark)");
      setIsDarkMode(matchMedia.matches);
      const handleChange = () => {
        setIsDarkMode(matchMedia.matches);
      };
      matchMedia.addEventListener("change", handleChange);
      return () => {
        matchMedia.removeEventListener("change", handleChange);
      };
    }
  }, [enableDarkMode]);
  const baseContainerClassName = enableDarkMode && isDarkMode ? "bg-gray-900 text-gray-200 border-gray-700" : "bg-white text-gray-900 border-gray-200";
  const baseTableClassName = enableDarkMode && isDarkMode ? "bg-gray-900 text-gray-200 divide-gray-700" : "bg-white text-gray-900 divide-gray-300";
  const baseThClassName = enableDarkMode && isDarkMode ? "text-gray-300" : "text-gray-900";
  const baseTdClassName = enableDarkMode && isDarkMode ? "text-gray-300" : "text-gray-900";
  const baseTrClassName = (index) => index % 2 === 0 ? enableDarkMode && isDarkMode ? "bg-gray-800" : "bg-white" : enableDarkMode && isDarkMode ? "bg-gray-700" : "bg-gray-50";
  const containerClassName = disableDefaultStyles ? customClassNames.container || "" : `${baseContainerClassName} px-4 sm:px-6 lg:px-8 ${customClassNames.container || ""}`;
  const tableClassName = disableDefaultStyles ? customClassNames.table || "" : `${baseTableClassName} min-w-full divide-y ${customClassNames.table || ""}`;
  const thClassName = disableDefaultStyles ? customClassNames.th || "" : `${baseThClassName} py-3.5 pl-4 pr-3 text-left text-sm font-semibold sm:pl-3 ${customClassNames.th || ""}`;
  const trClassName = (index) => disableDefaultStyles ? customClassNames.tr || "" : `${baseTrClassName(index)} ${customClassNames.tr || ""}`;
  const tdClassName = disableDefaultStyles ? customClassNames.td || "" : `${baseTdClassName} whitespace-nowrap py-4 pl-4 pr-3 text-sm sm:pl-3 ${customClassNames.td || ""}`;
  return /* @__PURE__ */ jsx2("div", { className: containerClassName, children: /* @__PURE__ */ jsx2("div", { className: "mt-8 flow-root", children: /* @__PURE__ */ jsx2("div", { className: "-mx-4 -my-2 overflow-x-auto sm:-mx-6 lg:-mx-8", children: /* @__PURE__ */ jsx2("div", { className: "inline-block min-w-full py-2 align-middle sm:px-6 lg:px-8", children: /* @__PURE__ */ jsxs2("table", { className: tableClassName, children: [
    /* @__PURE__ */ jsx2("thead", { children: /* @__PURE__ */ jsxs2("tr", { children: [
      Array.from({ length: 4 }).map((_, index) => /* @__PURE__ */ jsx2("th", { scope: "col", className: thClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 100 }) }, index)),
      /* @__PURE__ */ jsx2("th", { scope: "col", className: thClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 50 }) })
    ] }) }),
    /* @__PURE__ */ jsx2("tbody", { children: Array.from({ length: 10 }).map((_, index) => /* @__PURE__ */ jsxs2("tr", { className: trClassName(index), children: [
      Array.from({ length: 4 }).map((_2, colIndex) => /* @__PURE__ */ jsx2("td", { className: tdClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 150 }) }, colIndex)),
      /* @__PURE__ */ jsx2("td", { className: tdClassName, children: /* @__PURE__ */ jsx2(Skeleton, { width: 50 }) })
    ] }, index)) })
  ] }) }) }) }) });
};
var TableSkeleton_default = TableSkeleton;

// src/components/ActionDropdown.tsx
import { useState as useState2, useEffect as useEffect2, useRef } from "react";
import { createPortal } from "react-dom";
import { jsx as jsx3, jsxs as jsxs3 } from "react/jsx-runtime";
var ActionDropdown = ({
  item,
  index,
  actionTexts,
  actionFunctions,
  disableDefaultStyles = false,
  customClassNames = {},
  enableDarkMode = true
}) => {
  const [isDropdownOpen, setIsDropdownOpen] = useState2(false);
  const [isDarkMode, setIsDarkMode] = useState2(false);
  const [dropdownPosition, setDropdownPosition] = useState2({ top: 0, left: 0 });
  const buttonRef = useRef(null);
  const dropdownRef = useRef(null);
  const toggleDropdown = () => {
    if (buttonRef.current) {
      const rect = buttonRef.current.getBoundingClientRect();
      setDropdownPosition({
        top: rect.bottom + window.scrollY,
        left: Math.min(
          rect.left + window.scrollX - 10,
          window.innerWidth - 240
        )
      });
    }
    setIsDropdownOpen((prev) => !prev);
  };
  const handleClickOutside = (event) => {
    if (dropdownRef.current && !dropdownRef.current.contains(event.target) && buttonRef.current && !buttonRef.current.contains(event.target)) {
      setIsDropdownOpen(false);
    }
  };
  useEffect2(() => {
    document.addEventListener("mousedown", handleClickOutside);
    return () => {
      document.removeEventListener("mousedown", handleClickOutside);
    };
  }, []);
  useEffect2(() => {
    if (enableDarkMode) {
      const matchMedia = window.matchMedia("(prefers-color-scheme: dark)");
      setIsDarkMode(matchMedia.matches);
      const handleChange = () => setIsDarkMode(matchMedia.matches);
      matchMedia.addEventListener("change", handleChange);
      return () => {
        matchMedia.removeEventListener("change", handleChange);
      };
    }
  }, [enableDarkMode]);
  const handleDropdownClick = (event) => {
    event.stopPropagation();
  };
  const baseTdClassName = (i) => i % 2 === 0 ? isDarkMode ? "relative whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-3 bg-gray-800 text-gray-300" : "relative whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-3 bg-white text-gray-700" : isDarkMode ? "relative whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-3 bg-gray-700 text-gray-300" : "relative whitespace-nowrap py-4 pl-3 pr-4 text-right text-sm font-medium sm:pr-3 bg-gray-100 text-gray-700";
  const tdClassName = disableDefaultStyles ? customClassNames.actionTd || "" : `${baseTdClassName(index)} ${customClassNames.actionTd || ""}`;
  const baseButtonClassName = "focus:outline-none text-gray-700";
  const baseSvgClassName = "w-6 h-6 text-gray-700 hover:text-gray-900";
  const baseDropdownMenuClassName = "absolute z-50 mt-1 w-48 bg-gray-200 shadow-md rounded-lg text-gray-700";
  const baseDropdownItemClassName = "block w-full text-left px-4 py-2 text-sm text-gray-700 hover:bg-gray-300";
  const buttonClassName = disableDefaultStyles ? customClassNames.actionButton || "" : `${baseButtonClassName} ${customClassNames.actionButton || ""}`;
  const svgClassName = disableDefaultStyles ? customClassNames.actionSvg || "" : `${baseSvgClassName} ${customClassNames.actionSvg || ""}`;
  const dropdownMenuClassName = disableDefaultStyles ? customClassNames.dropdownMenu || "" : `${baseDropdownMenuClassName} ${customClassNames.dropdownMenu || ""}`;
  const dropdownItemClassName = disableDefaultStyles ? customClassNames.dropdownItem || "" : `${baseDropdownItemClassName} ${customClassNames.dropdownItem || ""}`;
  const dropdownMenu = /* @__PURE__ */ jsx3(
    "div",
    {
      ref: dropdownRef,
      className: dropdownMenuClassName,
      style: {
        top: dropdownPosition.top,
        left: dropdownPosition.left,
        transform: "translateX(-10%)"
      },
      onClick: handleDropdownClick,
      children: actionTexts.map((text, i) => /* @__PURE__ */ jsx3(
        "button",
        {
          onClick: () => {
            actionFunctions[i](item);
            setIsDropdownOpen(false);
          },
          className: dropdownItemClassName,
          children: text
        },
        `action-${text}`
      ))
    }
  );
  return /* @__PURE__ */ jsxs3("td", { className: tdClassName, children: [
    /* @__PURE__ */ jsx3(
      "button",
      {
        ref: buttonRef,
        onClick: toggleDropdown,
        className: buttonClassName,
        children: /* @__PURE__ */ jsx3(
          "svg",
          {
            xmlns: "http://www.w3.org/2000/svg",
            fill: "none",
            viewBox: "0 0 24 24",
            stroke: "currentColor",
            className: svgClassName,
            children: /* @__PURE__ */ jsx3(
              "path",
              {
                strokeLinecap: "round",
                strokeLinejoin: "round",
                strokeWidth: 2,
                d: "M12 6h.01M12 12h.01M12 18h.01"
              }
            )
          }
        )
      }
    ),
    isDropdownOpen && createPortal(dropdownMenu, document.body)
  ] }, `actions-${index}`);
};
var ActionDropdown_default = ActionDropdown;

// src/components/TableComponent.tsx
import Link from "next/link";

// src/utils/helpers.ts
var formatDate = (date, includeTime = false) => {
  const options = includeTime ? {
    year: "numeric",
    month: "short",
    day: "numeric",
    hour: "2-digit",
    minute: "2-digit"
  } : { year: "numeric", month: "short", day: "numeric" };
  return date.toLocaleDateString(void 0, options);
};
var isDateString = (str) => {
  if (str.length < 10) return false;
  const parsedDate = Date.parse(str);
  return !isNaN(parsedDate) && !isNaN(new Date(parsedDate).getTime());
};
var trimText = (text, maxLength) => text.length > maxLength ? `${text.slice(0, maxLength)}...` : text;

// src/components/PaginationComponent.tsx
import { useState as useState3, useEffect as useEffect3 } from "react";
import { jsx as jsx4, jsxs as jsxs4 } from "react/jsx-runtime";
var PaginationComponent = ({
  page,
  setPage,
  totalPages,
  disableDefaultStyles = false,
  customClassNames = {},
  enableDarkMode = true
}) => {
  const [isDarkMode, setIsDarkModeState] = useState3(false);
  useEffect3(() => {
    if (enableDarkMode) {
      const matchMedia = window.matchMedia("(prefers-color-scheme: dark)");
      setIsDarkModeState(matchMedia.matches);
      const handleChange = () => setIsDarkModeState(matchMedia.matches);
      matchMedia.addEventListener("change", handleChange);
      return () => {
        matchMedia.removeEventListener("change", handleChange);
      };
    }
  }, [enableDarkMode]);
  const baseButtonClassName = disableDefaultStyles ? customClassNames.button || "" : `px-3 py-1 mx-1 rounded-md ${isDarkMode ? "bg-gray-800 text-white hover:bg-gray-700" : "bg-gray-200 text-gray-800 hover:bg-gray-300"}`;
  const disabledButtonClassName = disableDefaultStyles ? customClassNames.buttonDisabled || "" : `opacity-50 cursor-not-allowed ${baseButtonClassName}`;
  const pageInfoClassName = disableDefaultStyles ? customClassNames.pageInfo || "" : `px-3 py-1 mx-1 text-sm ${isDarkMode ? "text-gray-300" : "text-gray-700"}`;
  return /* @__PURE__ */ jsxs4(
    "div",
    {
      className: disableDefaultStyles ? customClassNames.container || "" : "flex justify-center items-center mt-4",
      children: [
        /* @__PURE__ */ jsx4(
          "button",
          {
            disabled: page === 1,
            onClick: () => setPage(1),
            className: page === 1 ? disabledButtonClassName : baseButtonClassName,
            children: "First"
          }
        ),
        /* @__PURE__ */ jsx4(
          "button",
          {
            disabled: page === 1,
            onClick: () => setPage(page - 1),
            className: page === 1 ? disabledButtonClassName : baseButtonClassName,
            children: "Previous"
          }
        ),
        /* @__PURE__ */ jsxs4("span", { className: pageInfoClassName, children: [
          "Page ",
          /* @__PURE__ */ jsx4("strong", { children: page }),
          " of ",
          /* @__PURE__ */ jsx4("strong", { children: totalPages })
        ] }),
        /* @__PURE__ */ jsx4(
          "button",
          {
            disabled: page === totalPages,
            onClick: () => setPage(page + 1),
            className: page === totalPages ? disabledButtonClassName : baseButtonClassName,
            children: "Next"
          }
        ),
        /* @__PURE__ */ jsx4(
          "button",
          {
            disabled: page === totalPages,
            onClick: () => setPage(totalPages),
            className: page === totalPages ? disabledButtonClassName : baseButtonClassName,
            children: "Last"
          }
        )
      ]
    }
  );
};
var PaginationComponent_default = PaginationComponent;

// src/components/TableComponent.tsx
import { Fragment, jsx as jsx5, jsxs as jsxs5 } from "react/jsx-runtime";
function TableComponent({
  columns,
  data,
  props,
  actions,
  actionTexts,
  loading,
  actionFunctions,
  searchValue,
  disableDefaultStyles = false,
  customClassNames = {},
  renderRow,
  rowOnClick,
  enableDarkMode = true,
  enablePagination = false,
  page = 1,
  setPage,
  itemsPerPage = 10,
  totalPages,
  sortableProps = [],
  formatValue,
  noContentProps
}) {
  const [isDarkMode, setIsDarkMode] = useState4(false);
  const [expandedCells, setExpandedCells] = useState4({});
  const [sortProp, setSortProp] = useState4(null);
  const [sortOrder, setSortOrder] = useState4("none");
  const [frozenColumns, setFrozenColumns] = useState4({});
  const [hiddenColumns, setHiddenColumns] = useState4(/* @__PURE__ */ new Set());
  const [headerDropdown, setHeaderDropdown] = useState4({});
  const [columnWidths, setColumnWidths] = useState4(
    {}
  );
  const [isResizing, setIsResizing] = useState4(null);
  const resizingRef = useRef2(
    null
  );
  const tableRef = useRef2(null);
  useEffect4(() => {
    if (enableDarkMode) {
      const matchMedia = window.matchMedia("(prefers-color-scheme: dark)");
      setIsDarkMode(matchMedia.matches);
      const handleChange = () => setIsDarkMode(matchMedia.matches);
      matchMedia.addEventListener("change", handleChange);
      return () => {
        matchMedia.removeEventListener("change", handleChange);
      };
    }
  }, [enableDarkMode]);
  useEffect4(() => {
    const handleMouseMove = (e) => {
      if (isResizing && resizingRef.current) {
        const delta = e.clientX - resizingRef.current.startX;
        const newWidth = Math.max(100, resizingRef.current.startWidth + delta);
        setColumnWidths((prev) => ({
          ...prev,
          [isResizing]: newWidth
        }));
      }
    };
    const handleMouseUp = () => {
      setIsResizing(null);
      resizingRef.current = null;
    };
    if (isResizing) {
      document.addEventListener("mousemove", handleMouseMove);
      document.addEventListener("mouseup", handleMouseUp);
    }
    return () => {
      document.removeEventListener("mousemove", handleMouseMove);
      document.removeEventListener("mouseup", handleMouseUp);
    };
  }, [isResizing]);
  useEffect4(() => {
    const handleClickOutside = (event) => {
      const target = event.target;
      Object.keys(headerDropdown).forEach((key) => {
        if (headerDropdown[key]) {
          const element = document.getElementById(`header-dropdown-${key}`);
          if (element && !element.contains(target)) {
            setHeaderDropdown((prev) => ({ ...prev, [key]: false }));
          }
        }
      });
    };
    document.addEventListener("click", handleClickOutside);
    return () => document.removeEventListener("click", handleClickOutside);
  }, [headerDropdown]);
  const startResize = (prop, e) => {
    e.preventDefault();
    const column = document.querySelector(`[data-column="${prop}"]`);
    if (column) {
      setIsResizing(prop);
      resizingRef.current = {
        startX: e.clientX,
        startWidth: column.getBoundingClientRect().width
      };
    }
  };
  const toggleHeaderDropdown = (prop, e) => {
    e.preventDefault();
    e.stopPropagation();
    setHeaderDropdown((prev) => {
      const newState = Object.keys(prev).reduce(
        (acc, key) => ({
          ...acc,
          [key]: false
        }),
        {}
      );
      return {
        ...newState,
        [prop]: !prev[prop]
      };
    });
  };
  const toggleFreeze = (prop, position) => {
    setFrozenColumns((prev) => {
      const current = prev[prop];
      return {
        ...prev,
        [prop]: current === position ? null : position
      };
    });
    setHeaderDropdown((prev) => ({ ...prev, [prop]: false }));
  };
  const toggleColumnVisibility = (prop) => {
    setHiddenColumns((prev) => {
      const newSet = new Set(prev);
      if (newSet.has(prop)) {
        newSet.delete(prop);
      } else {
        newSet.add(prop);
      }
      return newSet;
    });
    setHeaderDropdown((prev) => ({ ...prev, [prop]: false }));
  };
  if (loading) {
    return /* @__PURE__ */ jsx5(TableSkeleton_default, { enableDarkMode });
  }
  if (!data || data.length === 0) {
    return /* @__PURE__ */ jsx5(NoContentComponent_default, { ...noContentProps });
  }
  let filteredData = data;
  if (searchValue) {
    filteredData = data.filter((item) => {
      return props.some((prop) => {
        const value = item[prop];
        return String(value).toLowerCase().includes(searchValue.toLowerCase());
      });
    });
  }
  if (filteredData.length === 0) {
    return /* @__PURE__ */ jsx5(NoContentComponent_default, { ...noContentProps });
  }
  const handleSort = (col) => {
    if (!sortableProps.includes(col)) return;
    if (sortProp === col) {
      if (sortOrder === "none") {
        setSortOrder("asc");
      } else if (sortOrder === "asc") {
        setSortOrder("desc");
      } else {
        setSortOrder("none");
      }
    } else {
      setSortProp(col);
      setSortOrder("asc");
    }
  };
  let sortedData = [...filteredData];
  if (sortProp && sortOrder !== "none") {
    sortedData.sort((a, b) => {
      const aVal = a[sortProp];
      const bVal = b[sortProp];
      const aStr = String(aVal).toLowerCase();
      const bStr = String(bVal).toLowerCase();
      if (aStr < bStr) return sortOrder === "asc" ? -1 : 1;
      if (aStr > bStr) return sortOrder === "asc" ? 1 : -1;
      return 0;
    });
  }
  let paginatedData = sortedData;
  let calculatedTotalPages = totalPages ?? Math.ceil(sortedData.length / itemsPerPage);
  if (enablePagination) {
    if (totalPages !== void 0) {
      paginatedData = sortedData;
    } else {
      const startIndex = (page - 1) * itemsPerPage;
      const endIndex = startIndex + itemsPerPage;
      paginatedData = sortedData.slice(startIndex, endIndex);
    }
    if (page > calculatedTotalPages && setPage) {
      setPage(calculatedTotalPages);
    }
  }
  const baseTableClassName = !disableDefaultStyles ? `w-full divide-y ${enableDarkMode && isDarkMode ? "bg-gray-900 text-gray-200 divide-gray-700" : "bg-white text-gray-900 divide-gray-200"}` : "";
  const baseTheadClassName = !disableDefaultStyles && enableDarkMode ? isDarkMode ? "bg-gray-700 text-gray-300" : "bg-gray-50 text-gray-500" : "";
  const baseTbodyClassName = !disableDefaultStyles ? `divide-y ${enableDarkMode && isDarkMode ? "divide-gray-700" : "divide-gray-200"}` : "";
  const baseTrClassName = (index) => !disableDefaultStyles ? index % 2 === 0 ? isDarkMode ? "bg-gray-800" : "bg-white" : isDarkMode ? "bg-gray-700" : "bg-gray-100" : "";
  const baseTdClassName = !disableDefaultStyles ? isDarkMode ? "text-gray-300" : "text-gray-700" : "";
  const tableClassName = disableDefaultStyles ? customClassNames.table || "" : `${baseTableClassName} ${customClassNames.table || ""}`;
  const theadClassName = disableDefaultStyles ? customClassNames.thead || "" : `${baseTheadClassName} ${customClassNames.thead || ""}`;
  const tbodyClassName = disableDefaultStyles ? customClassNames.tbody || "" : `${baseTbodyClassName} ${customClassNames.tbody || ""}`;
  const getFreezeClass = (prop) => {
    const freezePosition = frozenColumns[prop];
    return freezePosition ? `freeze-${freezePosition}` : "";
  };
  const getSortIndicator = (prop) => {
    if (!sortableProps.includes(prop)) return null;
    const isActive = prop === sortProp;
    const icon = isActive && sortOrder === "desc" ? "\u25BC" : "\u25B2";
    return /* @__PURE__ */ jsx5(
      "span",
      {
        className: `sort-indicator ${isActive ? "text-blue-500" : "text-gray-400"}`,
        children: icon
      }
    );
  };
  const visibleProps = props.filter((prop) => !hiddenColumns.has(String(prop)));
  return /* @__PURE__ */ jsxs5(Fragment, { children: [
    /* @__PURE__ */ jsx5("div", { className: "overflow-x-auto pb-6", children: /* @__PURE__ */ jsxs5("table", { ref: tableRef, className: tableClassName, children: [
      /* @__PURE__ */ jsx5("thead", { className: theadClassName, children: /* @__PURE__ */ jsxs5("tr", { children: [
        columns.map((col, i) => {
          const prop = String(props[i]);
          if (hiddenColumns.has(prop)) return null;
          return /* @__PURE__ */ jsxs5(
            "th",
            {
              "data-column": prop,
              className: `relative ${getFreezeClass(prop)}`,
              style: {
                width: columnWidths[prop] || "auto",
                cursor: sortableProps.includes(prop) ? "pointer" : "default"
              },
              children: [
                /* @__PURE__ */ jsxs5("div", { className: "header-content", children: [
                  /* @__PURE__ */ jsxs5(
                    "div",
                    {
                      className: "header-text",
                      onClick: () => handleSort(prop),
                      children: [
                        getSortIndicator(prop),
                        col
                      ]
                    }
                  ),
                  /* @__PURE__ */ jsxs5("div", { className: "header-actions", children: [
                    /* @__PURE__ */ jsx5(
                      "button",
                      {
                        onClick: (e) => toggleHeaderDropdown(prop, e),
                        className: "p-1 hover:bg-gray-200 rounded-full dark:hover:bg-gray-600",
                        children: /* @__PURE__ */ jsx5(
                          "svg",
                          {
                            xmlns: "http://www.w3.org/2000/svg",
                            fill: "none",
                            viewBox: "0 0 24 24",
                            stroke: "currentColor",
                            className: "w-4 h-4",
                            children: /* @__PURE__ */ jsx5(
                              "path",
                              {
                                strokeLinecap: "round",
                                strokeLinejoin: "round",
                                strokeWidth: 2,
                                d: "M12 6h.01M12 12h.01M12 18h.01"
                              }
                            )
                          }
                        )
                      }
                    ),
                    headerDropdown[prop] && /* @__PURE__ */ jsxs5(
                      "div",
                      {
                        id: `header-dropdown-${prop}`,
                        className: "dropdown-menu",
                        children: [
                          /* @__PURE__ */ jsx5(
                            "button",
                            {
                              onClick: () => toggleFreeze(prop, "left"),
                              className: "dropdown-item",
                              children: frozenColumns[prop] === "left" ? "Unfreeze" : "Freeze Left"
                            }
                          ),
                          /* @__PURE__ */ jsx5(
                            "button",
                            {
                              onClick: () => toggleFreeze(prop, "right"),
                              className: "dropdown-item",
                              children: frozenColumns[prop] === "right" ? "Unfreeze" : "Freeze Right"
                            }
                          ),
                          /* @__PURE__ */ jsx5(
                            "button",
                            {
                              onClick: () => toggleColumnVisibility(prop),
                              className: "dropdown-item",
                              children: "Hide Column"
                            }
                          )
                        ]
                      }
                    )
                  ] })
                ] }),
                /* @__PURE__ */ jsx5(
                  "div",
                  {
                    className: `resizer ${isResizing === prop ? "resizing" : ""}`,
                    onMouseDown: (e) => startResize(prop, e)
                  }
                )
              ]
            },
            col
          );
        }),
        actions && actionTexts && /* @__PURE__ */ jsx5("th", { className: "relative", children: /* @__PURE__ */ jsx5("span", { className: "sr-only", children: actionTexts.join(", ") }) })
      ] }) }),
      /* @__PURE__ */ jsx5("tbody", { className: tbodyClassName, children: paginatedData.map((item, dataIndex) => {
        if (renderRow) {
          return /* @__PURE__ */ jsx5(
            "tr",
            {
              onClick: () => rowOnClick && rowOnClick(item),
              className: `${baseTrClassName(dataIndex)} ${rowOnClick ? "cursor-pointer" : ""}`,
              children: renderRow(item, dataIndex)
            },
            dataIndex
          );
        }
        return /* @__PURE__ */ jsxs5(
          "tr",
          {
            onClick: () => rowOnClick && rowOnClick(item),
            className: `${baseTrClassName(dataIndex)} ${rowOnClick ? "cursor-pointer" : ""}`,
            children: [
              visibleProps.map((prop) => {
                let value = item[prop];
                if (value === null || value === void 0 || value === "") {
                  value = "-";
                }
                const cellKey = `${dataIndex}-${String(prop)}`;
                const isExpanded = expandedCells[cellKey];
                let displayValue;
                if (formatValue) {
                  displayValue = formatValue(
                    String(value),
                    String(prop),
                    item
                  );
                } else {
                  if (typeof value === "string" && isDateString(value)) {
                    displayValue = formatDate(new Date(value), true);
                  } else if (Array.isArray(value)) {
                    let displayArray = value;
                    if (!isExpanded && displayArray.length > 5) {
                      displayArray = displayArray.slice(0, 5);
                    }
                    displayValue = /* @__PURE__ */ jsxs5("div", { className: "chip-container", children: [
                      displayArray.map((chip, idx) => /* @__PURE__ */ jsx5("span", { className: "chip", children: trimText(String(chip), 20) }, idx)),
                      !isExpanded && value.length > 5 && /* @__PURE__ */ jsxs5(
                        "span",
                        {
                          className: "more-chip",
                          onClick: (e) => {
                            e.stopPropagation();
                            setExpandedCells((prev) => ({
                              ...prev,
                              [cellKey]: true
                            }));
                          },
                          children: [
                            "+",
                            value.length - 5,
                            " more"
                          ]
                        }
                      )
                    ] });
                  } else if (typeof value === "string" && value.startsWith("http")) {
                    displayValue = /* @__PURE__ */ jsx5(Link, { href: value, children: /* @__PURE__ */ jsx5(
                      "span",
                      {
                        className: "text-blue-500 hover:underline",
                        onClick: (e) => e.stopPropagation(),
                        children: isExpanded ? value : trimText(value, 30)
                      }
                    ) });
                  } else {
                    displayValue = isExpanded ? String(value) : trimText(String(value), 30);
                  }
                }
                return /* @__PURE__ */ jsx5(
                  "td",
                  {
                    "data-column": String(prop),
                    className: `table-cell ${getFreezeClass(String(prop))}`,
                    style: {
                      width: columnWidths[String(prop)] || "auto"
                    },
                    onClick: (e) => {
                      e.stopPropagation();
                      setExpandedCells((prev) => ({
                        ...prev,
                        [cellKey]: !prev[cellKey]
                      }));
                    },
                    children: displayValue
                  },
                  String(prop)
                );
              }),
              actions && actionTexts && actionFunctions && /* @__PURE__ */ jsx5(
                ActionDropdown_default,
                {
                  item,
                  index: dataIndex,
                  actionTexts,
                  actionFunctions,
                  disableDefaultStyles,
                  customClassNames,
                  enableDarkMode
                }
              )
            ]
          },
          dataIndex
        );
      }) })
    ] }) }),
    enablePagination && page !== void 0 && setPage && /* @__PURE__ */ jsx5("div", { className: "fixed bottom-4 left-1/2 transform -translate-x-1/2 z-10", children: /* @__PURE__ */ jsx5(
      PaginationComponent_default,
      {
        page,
        setPage,
        totalPages: calculatedTotalPages,
        disableDefaultStyles,
        customClassNames: customClassNames.pagination,
        enableDarkMode
      }
    ) })
  ] });
}
var TableComponent_default = TableComponent;
export {
  ActionDropdown_default as ActionDropdown,
  NoContentComponent_default as NoContentComponent,
  TableComponent_default as TableComponent,
  TableSkeleton_default as TableSkeleton
};
